@@ -2,7 +2,7 @@
 __path__ = __import__('pkgutil').extend_path(__path__, __name__)
 
 
-from .application import Application
+from .application import BaseApplication, Application
 from .validation import validate
 from .contenttypes import contenttype, binary, utf8, json, text, html
 from .lazyattribute import lazyattribute
@@ -13,6 +13,7 @@ from .statuses import HTTPStatus, statuscode, status, badrequest, \
     unauthorized, forbidden, notfound, methodnotallowed, conflict, gone, \
     preconditionfailed, notmodified, internalservererror, badgateway, \
     movedpermanently, found
+from .rewrite import Rewrite
 
 
-__version__ = '3.1.0'
+__version__ = '3.2.0'
